@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import division # 1/2 == .5 (par defaut, 1/2 == 0)
 
 #    WxGeometrie
 #    Dynamic geometry, graph plotter, and more for french mathematic teachers.
@@ -23,7 +22,7 @@ from __future__ import division # 1/2 == .5 (par defaut, 1/2 == 0)
 # Ce module sert à tester que toutes les dépendances sont satisfaites,
 # et à y remédier dans le cas contraire (si possible).
 
-import sys, imp, platform
+import sys, imp, platform, os, shutil, subprocess
 
 # ------------------------------------------------------------------------------
 # CONFIGURATION
@@ -32,17 +31,18 @@ import sys, imp, platform
 from .version import NOMPROG
 
 # Les valeurs sont les noms des paquets sous Debian/Ubuntu.
-dependances = {'PyQt4': 'python-qt4',
-               'matplotlib': 'python-matplotlib',
-               'scipy': 'python-scipy',
-               'numpy': 'python-numpy',
-               'mpmath': 'python-mpmath',
-               'sip': 'python-sip',
-               'PyQt4.Qsci': 'python-qscintilla2',
+dependances = {'PyQt5': 'python3-pyqt5',
+               'matplotlib': 'python3-matplotlib',
+               'scipy': 'python3-scipy',
+               'numpy': 'python3-numpy',
+               'mpmath': 'python3-mpmath',
+               'sip': 'python3-sip',
+               'PyQt5.Qsci': 'python3-pyqt5.qsci',
+               'PyQt5.QtSvg': 'python3-pyqt5.qtsvg',
                }
 
-python_version_min = (2, 6)
-python_version_max = (2, 7)
+python_version_min = (3, 5)
+python_version_max = (3, 99)
 
 plateforme = platform.system() #'Windows' ou 'Linux' par exemple.
 
@@ -50,7 +50,7 @@ plateforme = platform.system() #'Windows' ou 'Linux' par exemple.
 # Utiliser une installation LaTeX existante (meilleur rendu mais très lent !)
 latex = False
 latex_unicode = True
-moteur_de_rendu = 'Qt4Agg'
+moteur_de_rendu = 'Qt5Agg'
 
 # ------------------------------------------------------------------------------
 
@@ -62,16 +62,16 @@ def tester_dependances():
     # Make sure I have the right Python version.
     version_python_supportee = True
     if sys.version_info[:2] < python_version_min:
-        print(u" ** Erreur fatale **")
-        print(NOMPROG + u" nécessite Python %d.%d au minimum." % python_version_min)
+        print(" ** Erreur fatale **")
+        print(NOMPROG + " nécessite Python %d.%d au minimum." % python_version_min)
         version_python_supportee = False
     elif sys.version_info[:2] > python_version_max:
-        print(u" ** Erreur fatale **")
-        print(NOMPROG + u" supporte Python %d.%d au maximum." % python_version_max)
+        print(" ** Erreur fatale **")
+        print(NOMPROG + " supporte Python %d.%d au maximum." % python_version_max)
         version_python_supportee = False
 
     if not version_python_supportee:
-        print(u"Python %d.%d détecté." % sys.version_info[:2])
+        print("Python %d.%d détecté." % sys.version_info[:2])
         sys.exit(-1)
 
     # Test for dependencies:
@@ -90,24 +90,57 @@ def tester_dependances():
         except ImportError:
             modules_manquants.append(module_name)
 
-    if modules_manquants and plateforme == 'Linux':
+    if modules_manquants and plateforme == 'Linux' and shutil.which('apt'):
         paquets = [dependances[module] for module in modules_manquants]
-        import dbus
-        try:
-            bus = dbus.SessionBus()
-            try:
-                proxy = bus.get_object('org.freedesktop.PackageKit', '/org/freedesktop/PackageKit')
-                iface = dbus.Interface(proxy, 'org.freedesktop.PackageKit.Modify')
-                iface.InstallPackageNames(dbus.UInt32(0), paquets, "show-confirm-search,hide-finished", timeout=1000)
-                modules_manquants = []
-            except dbus.DBusException, e:
-                print 'Unable to use PackageKit: %s' % str(e)
-        except dbus.DBusException, e:
-            print 'Unable to connect to dbus: %s' % str(e)
+        for paquet in paquets:
+            msg = "WARNING: Le module %s manque." % paquet
+            deco = len(msg)*'*'
+            print(deco)
+            print(msg)
+            print(deco)
+            print("INSTALLATION via apt install...")
+            subprocess.run(['sudo', 'apt', 'install', paquet])
+        print('Des modules indispensables ont été installés.')
+        print('Redémarrage de Géophar...')
+        os.execv(sys.executable, [sys.executable] + sys.argv)
+        sys.exit()
+
 
     if modules_manquants:
-        print(u'** Erreur fatale **\nLes modules suivants sont introuvables !')
-        print(u'MODULE(S) MANQUANT(S): %s.' % ', '.join(modules_manquants))
+        try:
+            # Try to install missing modules using pip.
+            import pip
+            for module in modules_manquants:
+                pip.main(["install", "--user", module])
+            # This allows the modules to be imported during current python session.
+            # See https://stackoverflow.com/questions/40711133/pip-maininstall-user-not-working.
+            home_folder = os.path.expanduser("~")
+            user_site_packages_folder = "{}/.local/lib/python2.7/site-packages".format(home_folder)
+            if user_site_packages_folder not in sys.path:
+                sys.path.append(user_site_packages_folder)
+            modules_manquants = []
+        except ImportError:
+            pass
+
+    # ~ if modules_manquants and plateforme == 'Linux':
+        # ~ paquets = [dependances[module] for module in modules_manquants]
+        # ~ import dbus
+        # ~ try:
+            # ~ bus = dbus.SessionBus()
+            # ~ try:
+                # ~ proxy = bus.get_object('org.freedesktop.PackageKit', '/org/freedesktop/PackageKit')
+                # ~ iface = dbus.Interface(proxy, 'org.freedesktop.PackageKit.Modify')
+                # ~ iface.InstallPackageNames(dbus.UInt32(0), paquets, "show-confirm-search,hide-finished", timeout=10000)
+                # ~ modules_manquants = []
+            # ~ except dbus.DBusException as e:
+                # ~ print('Unable to use PackageKit: %s' % str(e))
+        # ~ except dbus.DBusException as e:
+            # ~ print('Unable to connect to dbus: %s' % str(e))
+
+
+    if modules_manquants:
+        print('** Erreur fatale **\nLes modules suivants sont introuvables !')
+        print('MODULE(S) MANQUANT(S): %s.' % ', '.join(modules_manquants))
         sys.exit(-1)
 
 
@@ -130,6 +163,8 @@ def configurer_dependances():
     except ImportError:
         print("Warning: sip not found.")
 
+    import PyQt5
+
     # ---------------------------
     # Configuration de Matplotlib
     # ---------------------------
@@ -139,6 +174,8 @@ def configurer_dependances():
     except ImportError:
         pass
     import matplotlib
+    matplotlib.rcParams['backend'] = 'Qt5Agg'
+    matplotlib.rcParams['backend.qt5'] ='PyQt5'
     matplotlib.use(moteur_de_rendu, warn=False)
     matplotlib.rcParams['text.usetex'] = latex
     matplotlib.rcParams["text.latex.unicode"] = latex_unicode
@@ -150,5 +187,7 @@ def configurer_dependances():
     #matplotlib.rcParams['font.monospace'] ='STIXGeneral'
     matplotlib.rcParams['mathtext.fontset'] ='stix'
 
+
+
     # import pylab_ as pylab
     # le fichier pylab_.py est modifie lors d'une "compilation" avec py2exe
